# Workflows API

High-level workflow helpers for oils, heating, QC, and protocol utilities.

::: foodspec.apps.oils

::: foodspec.apps.heating

::: foodspec.apps.qc

::: foodspec.apps.protocol_validation

